@@ -1,7 +1,6 @@
 //! Async [`TempDir`] for testing.
 
 use crate::error::Error;
-use async_trait::async_trait;
 use base64::{self, encode_config};
 use ring::rand::{SecureRandom, SystemRandom};
 use std::{fs as fsstd, path::PathBuf};
@@ -13,14 +12,8 @@ pub struct TempDir(pub PathBuf);
 /// Implemented to create a temporary directory with a random 8 byte
 /// base64 url string as a name. Drop implemented to remove directory
 /// when [`TempDir`] goes out of scope.
-#[async_trait]
-pub trait TempFrom<T> {
-    async fn from_str(path_str: &str) -> Result<T, Error>;
-}
-
-#[async_trait]
-impl TempFrom<TempDir> for TempDir {
-    async fn from_str(path_str: &str) -> Result<Self, Error> {
+impl TempDir {
+    pub async fn from_str(path_str: &str) -> Result<Self, Error> {
         if path_str.chars().last().unwrap() != '/' {
             return Err(Error::MissingTrailingSlash);
         }
